:tocdepth: 2

Bibliography
============

.. [Adan2006] Víctor Adán.
   "Music <-> Geometry <-> Meta-Music."
   Draft February 12, 2006.

.. [AgonAssayagBresson2006] Carlos Agon, Gérard Assayag, Jean Bresson.
   *The OM Composer's Book 1.*
   Éditions Delatour, Paris. 2006.    

.. [AgonHaddadAssayag2002] Carlos Agon, Karim Haddad & Gerard Assayag. 
   "Répresentation et rendu de structures rhythmiques."
   *Journées d'Informatique Musicale*, 9th ed., Marseille, 29 - 31 May 2002.

.. [Alegant1993] Brian Alegant.
   *The seventy-seven partitions of the aggregate:
   Analytical and theoretical implications.*
   Doctoral Dissertation.
   The University of Rochester, Eastman School of Music. 1993.

.. [AndreattaBardezRahn2008] Moren Andreatta, Jean-Michel Bardez and John Rahn.
   *Around Set Theory.*
   Éditions Delatour, Paris. 2008.

.. [Ariza2005] Christopher Ariza.
   *An Open Design for Computer-Aided Algorithmic Music Composition: athenaCL.*
   Dissertation.com, Boca Raton. 2005.

.. [BačaAdan2007] Trevor Bača & Víctor Adán. 
   "Cuepatlahto and Lascaux:
   two approaches to the formalized control of musical score."
   Draft June 7, 2007.

.. [BačaOberholtzerTreviñoAdán2015] Trevor Bača, Josiah Wolf Oberholtzer,
   Jeffrey Treviño & Víctor Adán.
   "Abjad: An Open-Software System For Formalized Score Control."
   2015.

.. [BressonAgonAssayag2008] Jean Bresson, Carlos Agon, Gérard Assayag.
   *The OM Composer's Book 2.*
   Éditions Delatour, Paris. 2008

.. [Carter2002] Eliot Carter.
   *Harmony Book.*
   Nicholas Hopkins and John F. Link, eds.
   Carl Fischer, New York. 2002.

.. [Forte1973] Alan Forte.
   The Structure of Atonal Music.
   Yale University Press, New Haven. 1973.

.. [Haddad] Karim Haddad. 
   "Le Temps comme Territoire: pour une géographie temporelle."

.. [Kampela1998] Arthur Kampela.
   *Uma Faca Só Lâmina.*
   Doctoral Dissertation.
   Columbia University, NY, NY. 1998.

.. [Malt2008] Mikhaïl Malt.
   "Some Considerations on Brian Ferneyhough's Musical Language 
   Through His Use of CAC --
   Part I: Time and Rhythmic Structures."
   In Bresson, Agon and Assayag (2008).

.. [MazzolaAhn2007] Guerino Mazzola and Yun-Kang Ahn.
   *La vérité du beau dans la musique.*
   Éditions Delatour, Paris. 2007.

.. [Morris1987] Robert Morris. 
   *Composition with Pitch-Classes.*
   Yale University Press, New Haven. 1987.

.. [Nauert1997] Paul Nauert.
   *Timespan Formation in Nonmetric, Posttonal Music.*
   Doctoral Dissertation.
   Columbia University, NY, NY. 1997.

.. [NienhuysNieuwenhuizen2003] Han-Wen Nienhuys & Jan Nieuwenhuizen. 
   "Lilypond: A system for automated music engraving. "
   *Proceedings of the XIV Colloquium on Musical Informatics.*
   Firenze, Italy. May 8 - 10, 2003.

.. [Oberholtzer2015] Josiah Wolf Oberholtzer.
   *A Computational Model of Music Composition.*
   Doctoral Dissertation.
   Harvard University, Graduate School of Arts and Sciences.
   2015.

.. [RebhahnSchäfer] Michael Rebhah and Thomas Schäfer.
   *Darmstädter Beiträge zur Neuen Musik.* vol 21.
   Schott Music GmbH & Co. KG, Mainz. 2012.

.. [RiotteMesnage2006-1] André Riotte and Marcel Mesnage.
   *Formalisme et modèles musicaux. 1*
   Éditions Delatour, Paris. 2006.
   
.. [RiotteMesnage2006-2] André Riotte and Marcel Mesnage.
   *Formalisme et modèles musicaux. 2*
   Éditions Delatour, Paris. 2006.

.. [Ross1987] Ted Ross.
   *Teach Yourself The Art of Music Engraving and Processing.*
   Hansen House, Miami Beach. 1987.

.. [Selfridge-Field1997] Eleanor Selfridge-Field, ed.
   *Beyond MIDI: The Handbook of Musical Codes.*
   The MIT Press. Cambridge, Massachusetts. 1997.

.. [Treviño2013] Jeffrey Treviño.
   *Compositional and Analytic Applications of Automated Music Notation via
   Object-oriented Programming.*
   Doctoral Dissertation.
   University of California San Diego. 2013.

.. [Valle] Andrea Valle. 
   "GeoGraphy: Notazione musicale e composizione algorithmica."
   Centro Interdipartimentale di Ricerca sulla Multimedialità e l'Audiovisivo. 
   Università degli Studi di Torino.

.. [WulfsonBarrettWinter] Harris Wulfson, G. Douglas Barrett & Michael Winter. 
   "Automatic Notation Generators."
